# Unity ID

A value object implementation of an NC State Unity Identifier.

## Goals

* To provide a reusable custom type for Unity ID.

## Install

Via Composer.

*You must have an SSH-key with appropriate access to this repository to install*

``` json
{
	"repositories": [
        {
            "type": "vcs",
            "url": "git@github.ncsu.edu:mdwheele/unity.git"
        }
    ],
    "require": {
        "ncsu/unity": "~1.0"
    }
}
```

## Requirements

The following versions of PHP are supported by this version.

* PHP 5.3
* PHP 5.4
* PHP 5.5

## Documentation

### A user class with typehinted Unity id.

``` php
use NCSU\Unity\UnityID;

class User
{
    private $id;
    private $firstName;
    private $lastName;

    public function __construct(UnityID $id, $firstName, $lastName)
    {
        $this->id = $id;
        $this->firstName = $firstName;
        $this->lastName = $lastName;
    }

    /**
     * @return string String representation of user; e.g. "bafogert@ncsu.edu"
     */
    public function __toString()
    {
        return sprintf(
            "%s %s <%s@ncsu.edu>",
            $this->firstName,
            $this->lastName,
            (string)$this->id
        );
    }
}

```

## Testing

``` bash
$ phpunit
```

## Contributing

Contributions are **welcome** and will be fully **credited**.

We accept contributions via Pull Requests on [Github](https://github.ncsu.edu/ncstate-contrib/unity).

## Pull Requests

- **[PSR-2 Coding Standard](https://github.com/php-fig/fig-standards/blob/master/accepted/PSR-2-coding-style-guide.md)** - The easiest way to apply the conventions is to install [PHP Code Sniffer](http://pear.php.net/package/PHP_CodeSniffer).

- **Add tests!** - Your patch won't be accepted if it doesn't have tests.

- **Document any change in behaviour** - Make sure the README and any other relevant documentation are kept up-to-date.

- **Consider our release cycle** - We try to follow semver. Randomly breaking public APIs is not an option.

- **Create topic branches** - Don't ask us to pull from your master branch.

- **One pull request per feature** - If you want to do more than one thing, send multiple pull requests.

- **Send coherent history** - Make sure each individual commit in your pull request is meaningful. If you had to make multiple intermediate commits while developing, please squash them before submitting.

## Running Tests

``` bash
$ phpunit
```

**Happy coding**!

## License

The MIT License (MIT). Please see [License File](./LICENSE) for more information.