<?php

namespace NCSU\Unity;

use InvalidArgumentException;

/**
 * Class representing a valid Unity identifier.
 *
 * @author Dustin Wheeler <mdwheele@ncsu.edu>
 */
class UnityID
{
    /**
     * @var string
     */
    private $unityId;

    /**
     * @param string $unityId
     */
    public function __construct($unityId)
    {
        $this->squawkIfInvalidUnityId($unityId);
        $this->unityId = $unityId;
    }

    /**
     * Throws an exception if provided unity identifier is not valid.
     *
     * @param string $unityId
     *
     * @throws \InvalidArgumentException
     */
    private function squawkIfInvalidUnityId($unityId)
    {
        if ( ! $this->validateUnityIdString($unityId)) {
            throw new InvalidArgumentException('The Unity ID provided was invalid.');
        }
    }

    /**
     * Verifies validity of a unity identifier.
     *
     * @param string $unityId
     *
     * @return bool True if valid, false otherwise.
     */
    private function validateUnityIdString($unityId)
    {
        // This regular expression is the same that is used during the account provisioning process.
        $unityRegex = '((^[a-z]{1,6}\_?\-?[a-z]{1,6}$)|(^[a-z][0-9]{2}[a-z]{2}[0-9]{3}$)|(^[a-z]{1,4}_[a-z]$)|(^[a-z][a-z]{1,6}[0-9]{0,5}$))';

        return preg_match($unityRegex, $unityId) == 1;
    }

    /**
     * @return string
     */
    public function __toString()
    {
        return (string) $this->unityId;
    }

}
